Local Development
=================

To setup a local development environment, follow these steps:

Clone repository
----------------
::

    git clone https://github.com/KENET-KE/django-ldap-user-registration.git

Install requirements
--------------------
::
    pip install -r requirements.pip

Settings
--------

Create local settings as follows and adjust accordingly:

::

   $ cp local_settings.py.default local_settings.py

Refer to configuration